from distutils.core import setup

setup(
    name='artcat',
    version='3.11.1',
    description='A cat(1) like utility for text mode art',
    author='Wijnand Modderman-Lenstra',
    author_email='maze@pyth0n.org',
    scripts=['artcat'],
)
